#
# spec file for package prometheus-postgres_exporter
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2021 Silvio Moioli <moio@suse.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?rhel}
%if 0%{?rhel} >= 8
# Found compressed .debug_abbrev section, not attempting dwz compression
# DWARF version 0 unhandled
%global debug_package %{nil}
%endif
# Fix ERROR: No build ID note found in
%undefine _missing_build_ids_terminate_build
%{go_nostrip}
%endif

%if 0%{?sle_version} == 150300 && !0%{?is_opensuse}
%{go_nostrip}
%endif

#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%define project github.com/prometheus-community/postgres_exporter
Name:           prometheus-postgres_exporter
Version:        0.10.1
Release:        4.5
Obsoletes:      golang-github-wrouesnel-postgres_exporter < %version-%release
Provides:       golang-github-wrouesnel-postgres_exporter = %version-%release
Summary:        Prometheus exporter for PostgreSQL
License:        Apache-2.0
Group:          System/Management
URL:            https://prometheus.io/
Source:         postgres_exporter-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        prometheus-postgres_exporter.service
Source3:        prometheus-postgres_exporter.sysconfig
# This patch has been applied before generating vendor tarball
Patch1:         0001-Update-prometheus-exporter-toolkit-to-0.7.3.patch
BuildRequires:  fdupes
BuildRequires:  golang-github-prometheus-promu
BuildRequires:  golang-packaging
ExcludeArch:    s390
%if 0%{?rhel}
BuildRequires:  golang >= 1.18
Requires(pre):  shadow-utils
%else
BuildRequires:  golang(API) >= 1.20
Requires(pre):  user(prometheus)
Requires(pre):  group(prometheus)
Requires(pre):  shadow
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}
%{go_provides}

%description
Prometheus exporter for PostgreSQL server metrics. Supported PostgreSQL versions: 9.1 and up.

%prep
%autosetup -a 1 -n postgres_exporter-%{version}

# Avoid "Unknown lvalue 'XXX' in section 'Service'" errors from systemd on older releases
%if 0%{?sle_version} && 0%{?sle_version} < 150300 || 0%{?rhel} && 0%{?rhel} < 9
sed -r -i '/^(Protect(Clock|Home|Hostname|KernelLogs)|PrivateMounts)=/d' %{SOURCE2}
%endif

%build
%goprep github.com/prometheus-community/postgres_exporter
GOPATH=%{_builddir}/go promu build -v

%install
install -D -m 0755 %{_builddir}/postgres_exporter-%{version}/postgres_exporter %{buildroot}/%{_bindir}/prometheus-postgres_exporter

install -D -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/prometheus-postgres_exporter.service
install -D -m 0645 %{SOURCE3} %buildroot%{_fillupdir}/sysconfig.prometheus-postgres_exporter
%fdupes %{buildroot}

%pre
%if 0%{?rhel}
%define serviceuser prometheus
getent group %{serviceuser} >/dev/null || %{_sbindir}/groupadd -r %{serviceuser}
getent passwd %{serviceuser} >/dev/null || %{_sbindir}/useradd -r -g %{serviceuser} -d %{_localstatedir}/lib/%{serviceuser} -M -s /sbin/nologin %{serviceuser}
%else
%service_add_pre %{name}.service
%endif

%post
%if 0%{?rhel}
%systemd_post %{name}.service
%else
%service_add_post %{name}.service
%fillup_only -n %{name}
%endif

%preun
%if 0%{?rhel}
%systemd_preun %{name}.service
%else
%service_del_preun %{name}.service
%endif

%postun
%if 0%{?rhel}
%systemd_postun %{name}.service
%else
%service_del_postun %{name}.service
%endif

%files
%defattr(-,root,root,-)
%doc README.md
%license LICENSE
%{_bindir}/prometheus-postgres_exporter
%{_fillupdir}/sysconfig.prometheus-postgres_exporter
%{_unitdir}/prometheus-postgres_exporter.service

%changelog
* Tue Nov 21 2023 Marina Latini <marina.latini@suse.com>
- Remove duplicated call to systemd requirements
- Do not build debug if RHEL >= 8
- Do not strip if SUSE Linux Enterprise 15 SP3
- Build at least with with Go >= 1.18 on RHEL
- Build with Go >= 1.20 elsewhere
* Thu Apr 20 2023 Witek Bedyk <witold.bedyk@suse.com>
- Adapt the systemd service security configuration
  to be able to start it on RHEL systems and clones
- Create the prometheus user for RHEL systems and clones
* Wed Apr 19 2023 Witek Bedyk <witold.bedyk@suse.com>
- Add 0001-Update-prometheus-exporter-toolkit-to-0.7.3.patch
  * Fix authentication bypass via cache poisoning
    (CVE-2022-46146, bsc#1208060)
- Fix _service to pull correct version
* Mon May 16 2022 Witek Bedyk <witold.bedyk@suse.com>
- Use go_modules source service
- Upgrade to version 0.10.1:
  * Fix broken log-level for values other than debug (bsc#1208965)
* Wed May 11 2022 Stefan Bluhm <stefan.bluhm@clacee.eu>
- Version/release lines above first usage of those macros.
  gh#uyuni-project/uyuni#5418
* Tue May 10 2022 Witek Bedyk <witold.bedyk@suse.com>
- Prevent empty %%pre section
* Fri Apr 22 2022 Martin Seidl <mseidl@suse.de>
- Exclude s390 builds
* Fri Feb 11 2022 Stefan Bluhm <stefan.bluhm@clacee.eu>
- Updated for RHEL8.
* Wed Oct 20 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * prometheus-postgres_exporter.service
* Tue Aug 17 2021 Martin Seidl <mseidl@suse.de>
- Package rename (from golang-github-wrouesnel-postgres_exporter) (jsc#SLE-23051)
- Upgrade to version 0.10.0:
  * fix pg_replication_slots on postgresql versions 9.4 <> 10.0
- Remove:
  * architectures.patch
- Upgrade to version 0.9.0:
  * Remove duplicate column in queries.yml
  * Add query for 'pg_replication_slots'
  * Allow a custom prefix for metric namespace
  * Support connstring syntax when discovering databases
  * Fix pg_database_size_bytes metric in queries.yaml
  * Don't ignore errors in parseUserQueries
  * Recover when connection cannot be established at startup
  * Don't retry if an error occurs while connecting to the database
- Upgrade to version 0.8.0:
  * Export pg_stat_archiver metrics
  * Add support for 'DATA_SOURCE_URI_FILE' envvar
  * Added new field "master" to queries.yaml
  * If "master" is true, query will be call only on once database in instance
  * Change queries.yaml for work with autoDiscoveryDatabases options
    added current database name to metrics because any database in
    cluster maybe have the same table names
    added "master" field for query instance metrics
- Upgrade to version 0.7.0:
  * Rename pg_database_size to pg_database_size_bytes in queries.yml
  * Add support for optional namespace caching
  * Fix some autodiscovery problems
  * Don't stop generating fingerprint while encountering value with "=" sign
    (may resolve problems with passwords and special characters)
- Upgrade to version 0.6.0:
  * Add SQL for grant connect
  * Expose pg_current_wal_lsn_bytes
  * Provide more helpful default values for tables that have never been vacuumed
  * Fix pg_up metric returns last calculated value without explicit resetting
  * Discover only databases that are not templates and allow connections
  * Add --exclude-databases option
- Upgrade to version 0.5.1:
  * Add application_name as a label for pg_stat_replication metrics
- Upgrade to version 0.5.0:
  * Add `--auto-discover-databases` option,
    which automatically discovers and scrapes all databases
  * Add support for boolean data types as metrics
  * Replication lag is now expressed as a float and not truncated to an integer
  * When default metrics are disabled, no version metrics are collected anymore either
  * Fix exporter panic when postgres server goes down
  * Add support for collecting metrics from multiple servers
* Thu Jun  6 2019 jmc <jcavalheiro@suse.com>
- Add %%license macro for LICENSE file
* Sat Apr 13 2019 jcavalheiro@suse.com
- Fix ppc64le compile errors on SLE15-SP1
  - Use go1.9 as newer versions break magefile on this arch
- Refactor and cleanup spec file
- Rename systemd service to prometheus-postgres_exporter
* Thu Mar 28 2019 Johannes Renner <jrenner@suse.com>
- Enable building postgres_exporter for additional architectures
  (s390x, ppc64 and arm64)
- Add:
  * architectures.patch
* Wed Mar 27 2019 Michael Calmer <mc@suse.com>
- Upgrade to 0.4.7:
  - Added a query for v9.1 pg_stat_activity.
  - Add `--constantLabels` flag to allow applying fixed constant
    labels to metrics.
  - Support 'B' suffix in units.
* Wed Oct 31 2018 moio@suse.com
- Upgrade to 0.4.6:
  - Fix 32 and 64mb unit sizes, were not supported in pg_settings
  - Add commandline flag to disable default metrics
  - Bugfix for pg_up (it would always be -1)
  - pg_up is now refreshed based on database Ping() every scrape
  - Adds the following environment variables for overriding defaults:
  - `PG_EXPORTER_WEB_LISTEN_ADDRESS`
  - `PG_EXPORTER_WEB_TELEMETRY_PATH`
  - `PG_EXPORTER_EXTEND_QUERY_PATH`
  - Add Content-Type to HTTP landing page
  - Fix panic due to inconsistent label cardinality when using queries.yaml with queries which return extra columns
  - Add metric for whether the user queries YAML file parsed correctly.
    This also includes the filename and SHA256 sum allowing tracking of updates
  - Add pg_up metric to indicate whether the exporter was able to connect and Ping() the PG instance before a scrape
  - Fix broken link in landing page for `/metrics`
  - Add support for PostgreSQL 10
  - Add support for the 16kB unit when decoding pg_settings
  - Fix DSN logging
  - Ignore functions that cannot be executed during replication recovery
  - Add a `-version` flag finally
  - Add confirmed_flush_lsn to pg_stat_replication
  - Use pg_settings to retrieve runtime variables. Adds >180 new metrics and descriptions
* Thu Jun 14 2018 mc@suse.com
- start service after postgresql
* Wed Jun 13 2018 mc@suse.com
- add systemd service and config file
* Wed Mar 29 2017 moio@suse.com
- Initial version
